##########  components and core configuration ##########

export OIFS="./master.exe"
export OIFS_CORES=128
export FESOM="./fesom.x"
export FESOM_CORES=144
export RNFMAPPER="./rnfmap.exe"
export RNFMAPPER_CORES=1

export FESOM_USE_CPLNG="active"
export ECE_CPL_NEMO_LIM="false"
export ECE_CPL_FESOM_FESIM="false"
export ECE_AWI_CPL_FESOM="true"


echo "Number of cores per ensemble member : $(${FESOM_CORES} +${OIFS_CORES} +${RNFMAPPER_CORES} ) "
echo "Number of nodes to be used (48 cores per node): ${NODE_ALLOCATION}"


# to address issue with srun
COMPSS_MPI_TYPE=impi
export ECCODES_SAMPLES_PATH=/apps/ECCODES/2.8.0/INTEL/share/eccodes/ifs_samples/grib1/

# Sample invocation of this script:
# ./launch_mn4.sh 288 debug 1
# ./launch_mn4.sh 144 debug 3
# ./launch_mn4.sh 144 debug 1
# $1 number of cores needed by the task
# $2 QoS to be used (determines the queue)
# $3 number of simulations of the ensemble

EXP_ID=$(printf "%06d\n" $((1 + $RANDOM % 100000)))
#EXP_ID="awi3"
# prepare work folder
mkdir $EXP_ID
cd $EXP_ID
#cp -rf /home/bsc32/bsc32044/awi-cm3/tests/coupled/TCO95L91-CORE2-BASEFILES/* .
#cp -rf /home/bsc32/bsc32044/awi-cm3/tests/coupled/TCO95L91-CORE2-CONF/* .
cp -rf /home/bsc32/bsc32044/awicm3_ensemble/* .
rm -rf $EXP_ID


# launch the esm ensemble simulation with hecuba infraestructure  through COMPSs (WORKING)
if [[ "${USE_HECUBA-}" == "TRUE" ]]; then
        echo "Running with HECUBA ENABLED"
        enqueue_compss -t -g -d --sc_cfg=mn.cfg  \
               --qos=${QOS}  \
               --storage_props=$PWD/hecuba_lib/storage_props.cfg \
               --storage_home=$HECUBA_ROOT/compss \
               --job_name=esm_workflow  \
               --exec_time=120  \
               --keep_workingdir \
               --worker_working_dir=$PWD \
               --worker_in_master_cpus=48  \
               --num_nodes=${NODE_ALLOCATION}  \
               --pythonpath=$PWD:$HECUBA_ROOT/compss esm_simulation.py ${EXP_ID}

else
        echo "Running without HECUBA"
        enqueue_compss -t -g -d --sc_cfg=mn.cfg  \
               --qos=${QOS}  \
               --storage_props=$PWD/hecuba_lib/storage_props.cfg \
               --job_name=esm_workflow  \
               --exec_time=120  \
               --keep_workingdir \
               --worker_working_dir=$PWD \
               --worker_in_master_cpus=48  \
               --num_nodes=${NODE_ALLOCATION}  \
               --pythonpath=$PWD esm_simulation.py ${EXP_ID}
